Learn R Programming

skewlmm (version 1.1.3)

UTIdata: Data set for Unstructured Treatment Interruption Study

Description

Data set from a study of Unstructured Treatment Interruption in HIV-infected adolescents in four institutions in the USA. The main outcome is the HIV-1 RNA viral load, which is subject to censoring below the lower limit of detection of the assay (50 copies/mL). The censored observations are indicated by the variable RNAcens.

Usage

data(UTIdata)

Arguments

Format

This data frame contains the following columns:

Patid

patient ID

Days.after.TI

days after treatment interruption

Fup

follow-up months

RNA

viral load RNA

RNAcens

censoring indicator for viral load

Details

This dataset was copied from the lmec package, which was discontinued from CRAN in May 2022.

See Also

smn.clmm

Examples

Run this code
library(ggplot2)

data(UTIdata)
ggplot(UTIdata) + geom_line(aes(x=Fup, y=log10(RNA), group=Patid)) +
  geom_hline(yintercept=log10(50), color="red", linetype="dashed") +
  geom_hline(yintercept=log10(400), color="red", linetype="dashed") +
  labs(x="Time", y=bquote(log["10"]("RNA"))) + theme_bw()

# Proportion of censoring
prop.table(table(UTIdata$RNAcens))

Run the code above in your browser using DataLab