Learn R Programming

skewlmm (version 1.1.3)

boot_par: Parametric bootstrap for SMSN/SMN objects

Description

It generates and estimates B Monte Carlo samples identical to the fitted model.

Usage

boot_par(object, B = 100, seed = 123)

Value

A tibble of class lmmBoot with B lines, where each line contains the estimated parameters from a simulated sample.

Arguments

object

A smsn.lmm or smn.lmm object containing the fitted model to be updated.

B

Number of samples to be used.

seed

Seed to be used.

Author

Fernanda L. Schumacher, Larissa A. Matos and Victor H. Lachos

Details

This function provides an alternative for the asymptotic standard errors and confidence intervals given in summary, which may be helpful for small samples. Nevertheless, the computational cost is higher and it may take several minutes to get the results.

See Also

boot_ci, smsn.lmm, smn.lmm

Examples

Run this code
# \donttest{
fm1 = smn.lmm(nlme::Orthodont, formFixed=distance ~ age+Sex, groupVar="Subject")
b1 = boot_par(fm1, B=100)
boot_ci(b1)
# }

Run the code above in your browser using DataLab