Learn R Programming

skewlmm (version 1.1.3)

confint: Computes confidence intervals from smn.lmm and smsn.lmm fitted models

Description

Computes either asymptotical (based on normality from maximum likelihood estimators) or parametric bootstraped confidence intervals from a model fit.

Usage

# S3 method for SMN
confint(object, parm, level = 0.95, method, ...)
# S3 method for SMSN
confint(object, parm, level = 0.95, method, ...)

Value

A table containing the estimate and the respective confidence interval.

Arguments

object

An object inheriting from class SMN or SMSN

parm

A character indicating for which parameter the intervals should be returned. Available options: "beta" for fixed effects, or "all" for all parameters. Default is "all".

level

Confidence level to be used.

method

A character indicating with method should be used. "asymptotic" refers to traditional confidence intervals based on asymptotical normality from maximum likelihood estimators; "bootstrap" performs a parametric bootstrap method based on B samples (100 by default), and is only recommended to small to moderate sample sizes.

...

Additional arguments to be passed to boot_par.

See Also

smn.lmm, smsn.lmm, boot_par, boot_ci

Examples

Run this code
fm1 = smn.lmm(distance ~ age+Sex, data=nlme::Orthodont, groupVar="Subject")
confint(fm1)

Run the code above in your browser using DataLab