The fitted values are obtained by adding together the
population fitted values (based only on the fixed effects estimates)
and the estimated contributions of the random effects to the fitted
values at grouping levels.
Usage
# S3 method for SMN
fitted(object, ...)
Value
Vector of fitted values with length equal to nrow(data).
Arguments
object
An object inheriting from class SMN, representing
a fitted scale mixture normal linear mixed model.
...
Additional arguments.
Author
Fernanda L. Schumacher, Larissa A. Matos and Victor H. Lachos