The fitted values are obtained by adding together the population fitted values (based only on the fixed effects estimates) and the estimated contributions of the random effects to the fitted values at grouping levels.
# S3 method for SMNclmm
fitted(object, ...)Vector of fitted values with length equal to nrow(data).
An object inheriting from class SMNclmm, representing a fitted scale mixture normal linear mixed model with censored responses.
Additional arguments.
Fernanda L. Schumacher, Larissa A. Matos, Victor H. Lachos and Katherine L. Valeriano
smn.clmm, predict.SMNclmm