Learn R Programming

skewlmm (version 1.1.3)

fitted.SMSN: Extract smsn.lmm fitted values

Description

The fitted values are obtained by adding together the population fitted values (based only on the fixed effects estimates) and the estimated contributions of the random effects to the fitted values at grouping levels.

Usage

# S3 method for SMSN
fitted(object, ...)

Value

Vector of fitted values with length equal to nrow(data).

Arguments

object

An object inheriting from class SMSN, representing a fitted scale mixture skew-normal linear mixed model.

...

Additional arguments.

Author

Fernanda L. Schumacher, Larissa A. Matos and Victor H. Lachos

See Also

smsn.lmm, predict.SMSN

Examples

Run this code
fm1 = smsn.lmm(distance ~ age+Sex, data=nlme::Orthodont, groupVar="Subject",
               control=lmmControl(tol=.0001))
fitted(fm1)

Run the code above in your browser using DataLab