Learn R Programming

skewlmm (version 1.1.3)

formula: Formula from an smn.lmm and smsn.lmm models

Description

It returns the formula used for both fixed and random terms of the linear mixed model represented by object.

Usage

# S3 method for SMN
formula(x, ...)
# S3 method for SMSN
formula(x, ...)

Value

formFixed

Fixed effects formula

formRandom

Random effects formula

groupVar

Variable identified subjects or clusters

Arguments

x

An object inheriting from class SMN or SMSN

...

Additional arguments

See Also

smn.lmm, smsn.lmm, criteria

Examples

Run this code
fm1 = smn.lmm(distance ~ age+Sex, data=nlme::Orthodont, groupVar="Subject")
formula(fm1)

Run the code above in your browser using DataLab