Learn R Programming

skewlmm (version 1.1.3)

logLik: Log-likelihood of an smn.lmm and smsn.lmm models

Description

It returns the log-likelihood value of the linear mixed model represented by object evaluated at the estimated coefficients.

Usage

# S3 method for SMN
logLik(object, ...)
# S3 method for SMSN
logLik(object, ...)

Value

The log-likelihood value of the model represented by object evaluated at the estimated coefficients.

Arguments

object

An object inheriting from class SMN or SMSN

...

Additional arguments.

See Also

smn.lmm, smsn.lmm, criteria

Examples

Run this code
fm1 = smn.lmm(distance ~ age+Sex, data=nlme::Orthodont, groupVar="Subject")
logLik(fm1)

Run the code above in your browser using DataLab