Learn R Programming

skewlmm (version 1.1.3)

mahalDistCens: Mahalanobis distance from a smn.clmm object

Description

Returns the squared Mahalanobis distance from a fitted SMN-CLMM. Censored values are imputed using their conditional expectation from the fitting algorithm.

Usage

mahalDistCens(object)

Value

An object of class mahalDistCens containing the Mahalanobis distance.

Arguments

object

An object inheriting from class SMNclmm, representing a fitted scale mixture of normal censored linear mixed model.

Author

Fernanda L. Schumacher, Larissa A. Matos, Victor H. Lachos and Katherine L. Valeriano

References

Schumacher, F. L., Lachos, V. H., and Matos, L. A. (2021). Scale mixture of skew-normal linear mixed models with within-subject serial dependence. Statistics in Medicine 40(7), 1790-1810.

Zeller, C. B., Labra, F. V., Lachos, V. H. & Balakrishnan, N. (2010). Influence analyses of skew-normal/independent linear mixed models. Computational Statistics & Data Analysis, 54(5).

See Also

smn.clmm, plot.mahalDistCens