Learn R Programming

skewlmm (version 1.1.3)

nobs: Extract the number of observations from smn.lmm and smsn.lmm fitted models

Description

Extract the total number of observations from a model fit (considering all repeated measurements from all subjects or clusters).

Usage

# S3 method for SMN
nobs(object, ...)
# S3 method for SMSN
nobs(object, ...)

Value

A single integer, expected to be equal to nrow(data).

Arguments

object

An object inheriting from class SMN or SMSN

...

Additional arguments.

See Also

smn.lmm, smsn.lmm, criteria

Examples

Run this code
fm1 = smn.lmm(distance ~ age+Sex, data=nlme::Orthodont, groupVar="Subject")
nobs(fm1)

Run the code above in your browser using DataLab