Predicted values are obtained through conditional expectation. For details, see Schumacher, Lachos, and Matos (2021).
# S3 method for SMNclmm
predict(object, newData, ...)A data frame with covariates, groupVar and ypred, where ypred contains the predicted values from the response variable.
An object inheriting from class SMNclmm, representing
a fitted scale mixture normal linear mixed model.
A data frame for which response variable should be predicted, including covariates, groupVar and possibly timeVar. If missing or NULL, fitted values are returned.
Additional arguments.
Fernanda L. Schumacher, Larissa A. Matos, Victor H. Lachos and Katherine L. Valeriano
Schumacher, F. L., Lachos, V. H., and Matos, L. A. (2021). Scale mixture of skew-normal linear mixed models with within-subject serial dependence. Statistics in Medicine 40(7), 1790-1810.
smn.clmm, fitted.SMNclmm