Learn R Programming

skewlmm (version 1.1.3)

predict.SMSN: Prediction of future observations from an smsn.lmm object

Description

Predicted values are obtained through conditional expectation. For details, see Schumacher, Lachos, and Matos (2021).

Usage

# S3 method for SMSN
predict(object, newData, ...)

Value

A data frame with covariates, groupVar and ypred, where ypred contains the predicted values from the response variable.

Arguments

object

An object inheriting from class SMSN, representing a fitted scale mixture skew-normal linear mixed model.

newData

A data frame for which response variable should be predicted, including covariates, groupVar and possibly timeVar. If missing or NULL, fitted values are returned.

...

Additional arguments.

Author

Fernanda L. Schumacher, Larissa A. Matos and Victor H. Lachos

References

Schumacher, F. L., Matos, L. A., and Lachos, V. H. (2025). "skewlmm: An R Package for Fitting Skewed and Heavy-Tailed Linear Mixed Models." Journal of Statistical Software, 115(7), 1--32.

Schumacher, F. L., Lachos, V. H., and Matos, L. A. (2021). Scale mixture of skew-normal linear mixed models with within-subject serial dependence. Statistics in Medicine 40(7), 1790-1810.

See Also

smsn.lmm, fitted.SMSN

Examples

Run this code
# \donttest{
dat1 = nlme::Orthodont
fm1 = smsn.lmm(distance ~ age+Sex, data=subset(dat1, age<14), groupVar="Subject")
predict(fm1, subset(dat1, age==14))
# }

Run the code above in your browser using DataLab