The conditional residuals are obtained by subtracting the fitted values from the response vector, while the marginal residuals are obtained by subtracting only the fixed effects from the response vector.
Censored values are imputed using their conditional expectation from the fitting algorithm.
# S3 method for SMNclmm
residuals(object, level = "conditional", ...)Vector with the residuals of length equal to nrow(data).
An object inheriting from class SMNclmm, representing
a fitted scale mixture of normal censored linear mixed model.
Either "conditional", for obtaining conditional residuals, or "marginal", for marginal residuals.
Additional arguments.
Fernanda L. Schumacher, Larissa A. Matos, Victor H. Lachos and Katherine L. Valeriano
smn.clmm, mahalDistCens