It creates a simulated data set from SMSN-CLMM with several possible dependence structures, with an established censoring rate or a fixed limit of detectation (LOD).
rsmsn.clmm(time, ind, x, z, sigma2, D, beta, lambda=rep(0, nrow(D)),
depStruct="UNC", phi=NULL, distr="norm", nu=NULL, type="left",
pcens=0.10, LOD=NULL)A data frame containing time, the variable indicating groups (ind), the generated response variable (y), the censoring indicator variable (ci), the lower censoring limit (lcl), the upper censoring limit (ucl), and possible covariates.
Vector of length \(N\) containing times that should be used in data generation, where \(N\) indicates the total number of observations.
Vector of length \(N\) containing the variable which represents the subjects or groups.
Design matrix for fixed effects of dimension \(N\times p\).
Design matrix for random effects of dimension \(N \times q\).
Common variance parameter, such that \(\Sigma=\sigma^2*R\).
Variance matrix for random effects.
Vector of fixed effects parameter.
Skewness parameter of random effects.
Dependence structure. "UNC" for conditionally uncorrelated ("CI" is also accepted), "ARp" for AR(p) -- p is length(phi)--, "CS" for compound symmetry, "DEC" for DEC, "CAR1" for continuous-time AR(1), and "MA1" for moving average of order 1.
Parameter vector indexing the dependence structure.
Distribution that should be used. "norm" for normal, "t" for Student-t, "sn" for skew-normal, and "st" for skew-t.
Degrees of freedom for Student-t and skew-t distributions. It must be greater than 2.
left for left censoring and right for right censoring.
Desired censoring rate.
Desired limit of detectation. If LOD is provided, then pcens will be discarded.
Fernanda L. Schumacher, Larissa A. Matos, Victor H. Lachos and Katherine L. Valeriano
Matos, L. A., Prates, M. O., Chen, M. H., and Lachos, V. H. (2013). Likelihood-based inference for mixed-effects models with censored response using the multivariate-t distribution. Statistica Sinica 23(3), 1323-1345.
Lachos, V. H., A. Matos, L., Castro, L. M., and Chen, M. H. (2019). Flexible longitudinal linear mixed models for multiple censored responses data. Statistics in medicine, 38(6), 1074-1102.
smn.clmm