powered by
summary method for class "SMN".
summary
# S3 method for SMN summary(object, confint.level = 0.95, ...)
Estimated variance matrix from random effects (\(D\)).
Parameter estimates of variance from random errors (\(\Sigma\)). For recovering the error variance matrix use errorVar function.
errorVar
Estimated fixed effects, their standard errors and approximated confidence intervals.
Maximum log-likelihood value, AIC and BIC criteria.
An object inheriting from class SMN, representing a fitted scale mixture normal linear mixed model.
SMN
Level of the approximate confidence intervals presented.
Additional arguments.
Fernanda L. Schumacher, Larissa A. Matos and Victor H. Lachos
boot_par, smn.lmm, errorVar, plot.SMN, residuals.SMN
boot_par
smn.lmm
plot.SMN
residuals.SMN
# \donttest{ fm1 = smn.lmm(distance ~ age+Sex, data=nlme::Orthodont, groupVar="Subject") summary(fm1) # }
Run the code above in your browser using DataLab