boot_par: Parametric bootstrap for SMSN/SMN objects
Description
It generates and estimates B Monte Carlo samples identical to the fitted model.
Usage
boot_par(object, B = 100, seed = 123)
Value
A tibble of class lmmBoot with B lines, where each line contains the estimated parameters from a simulated sample.
Arguments
object
A smsn.lmm or smn.lmm object containing the fitted model to be updated.
B
Number of samples to be used.
seed
Seed to be used.
Author
Fernanda L. Schumacher, Larissa A. Matos and Victor H. Lachos
Details
This function provides an alternative for the asymptotic standard errors and confidence intervals given in summary, which may be helpful for small samples.
Nevertheless, the computational cost is higher and it may take several minutes to get the results.