powered by
It returns the formula used for both fixed and random terms of the linear mixed model represented by object.
# S3 method for SMN formula(x, ...) # S3 method for SMSN formula(x, ...)
Fixed effects formula
Random effects formula
Variable identified subjects or clusters
An object inheriting from class SMN or SMSN
SMN
SMSN
Additional arguments
smn.lmm, smsn.lmm, criteria
smn.lmm
smsn.lmm
criteria
fm1 = smn.lmm(distance ~ age+Sex, data=nlme::Orthodont, groupVar="Subject") formula(fm1)
Run the code above in your browser using DataLab