powered by
It returns the log-likelihood value of the linear mixed model represented by object evaluated at the estimated coefficients.
# S3 method for SMN logLik(object, ...) # S3 method for SMSN logLik(object, ...)
The log-likelihood value of the model represented by object evaluated at the estimated coefficients.
An object inheriting from class SMN or SMSN
SMN
SMSN
Additional arguments.
smn.lmm, smsn.lmm, criteria
smn.lmm
smsn.lmm
criteria
fm1 = smn.lmm(distance ~ age+Sex, data=nlme::Orthodont, groupVar="Subject") logLik(fm1)
Run the code above in your browser using DataLab