powered by
Extract the total number of observations from a model fit (considering all repeated measurements from all subjects or clusters).
# S3 method for SMN nobs(object, ...) # S3 method for SMSN nobs(object, ...)
A single integer, expected to be equal to nrow(data).
nrow(data)
An object inheriting from class SMN or SMSN
SMN
SMSN
Additional arguments.
smn.lmm, smsn.lmm, criteria
smn.lmm
smsn.lmm
criteria
fm1 = smn.lmm(distance ~ age+Sex, data=nlme::Orthodont, groupVar="Subject") nobs(fm1)
Run the code above in your browser using DataLab